==> libreoffice-fresh-sdk-25.2.3-4-x86_64.pkg.tar.zst: usr/share/doc/libreoffice/sdk/docs/idl/ref/servicecom_1_1sun_1_1star_1_1drawing_1_1Shape.js <==
var servicecom_1_1sun_1_1star_1_1drawing_1_1Shape =
[
    [ "InteropGrabBag", "servicecom_1_1sun_1_1star_1_1drawing_1_1Shape.html#a0757cef6c56ac96c756b2073c883f8ae", null ],
    [ "XPropertySet", "servicecom_1_1sun_1_1star_1_1drawing_1_1Shape.html#ae6872c0d73362de7c3f167030e03e1cf", null ],
    [ "XTolerantMultiPropertySet", "servicecom_1_1sun_1_1star_1_1drawing_1_1Shape.html#aeea8ad7e0ca85deb15bbed39a280557d", null ],
    [ "XGluePointsSupplier", "servicecom_1_1sun_1_1star_1_1drawing_1_1Shape.html#a437cf9adf6d63835724f5abd22de65cc", null ],
    [ "XShape", "servicecom_1_1sun_1_1star_1_1drawing_1_1Shape.html#adab20321c1eecb5d8434a81acc03fc20", null ],
    [ "XShapeDescriptor", "servicecom_1_1sun_1_1star_1_1drawing_1_1Shape.html#acd261de4974c7d2c48cedc30b347ae29", null ],
    [ "XComponent", "servicecom_1_1sun_1_1star_1_1drawing_1_1Shape.html#a3ee2eab6ea072f036a4548a48b0ed454", null ],
    [ "Decorative", "servicecom_1_1sun_1_1star_1_1drawing_1_1Shape.html#a4cf36267af04677eb9cdb6526e4aecda", null ],
    [ "Description", "servicecom_1_1sun_1_1star_1_1drawing_1_1Shape.html#a34409fed9d39281ada2d7ec172a52f9b", null ],
    [ "Hyperlink", "servicecom_1_1sun_1_1star_1_1drawing_1_1Shape.html#a060c49c5081c74c87cec34f8bfea3293", null ],
    [ "LayerID", "servicecom_1_1sun_1_1star_1_1drawing_1_1Shape.html#af37feca849685e9af8103c6b080ec331", null ],
    [ "LayerName", "servicecom_1_1sun_1_1star_1_1drawing_1_1Shape.html#adbfb5217b3399f617da03fea11e225e8", null ],
    [ "MoveProtect", "servicecom_1_1sun_1_1star_1_1drawing_1_1Shape.html#ab69af988a6e1eda2516005022e0420b7", null ],
    [ "Name", "servicecom_1_1sun_1_1star_1_1drawing_1_1Shape.html#a7ee9065718e6628dc7791b756fa6c0f9", null ],
    [ "NavigationOrder", "servicecom_1_1sun_1_1star_1_1drawing_1_1Shape.html#add98d6f3aac48cbf5ccd23af708034d9", null ],
    [ "Printable", "servicecom_1_1sun_1_1star_1_1drawing_1_1Shape.html#ad75a741ee6d8f45340ba0bbb7771f05b", null ],
    [ "RelativeHeight", "servicecom_1_1sun_1_1star_1_1drawing_1_1Shape.html#a83747b4d8c0a4a01350c25dd4c9ca006", null ],
    [ "RelativeHeightRelation", "servicecom_1_1sun_1_1star_1_1drawing_1_1Shape.html#af17d6377d90affc191c24d0a7bca7320", null ],
    [ "RelativeWidth", "servicecom_1_1sun_1_1star_1_1drawing_1_1Shape.html#a0a141b19661d6b1ab1aeb9487d3c7396", null ],
    [ "RelativeWidthRelation", "servicecom_1_1sun_1_1star_1_1drawing_1_1Shape.html#adb0178cce657fa0437f1329934f2f60f", null ],
    [ "ShapeUserDefinedAttributes", "servicecom_1_1sun_1_1star_1_1drawing_1_1Shape.html#aff9c06d4f7e22a306bb583bda636e87a", null ],
    [ "SizeProtect", "servicecom_1_1sun_1_1star_1_1drawing_1_1Shape.html#a51d9e13d885023067ad0e080b1560b92", null ],
    [ "Style", "servicecom_1_1sun_1_1star_1_1drawing_1_1Shape.html#aa5ea39996be0cb26d1e9bc347db9304c", null ],
    [ "Title", "servicecom_1_1sun_1_1star_1_1drawing_1_1Shape.html#aa7b633091e7820b835d04d0d5fc197c7", null ],
    [ "Transformation", "servicecom_1_1sun_1_1star_1_1drawing_1_1Shape.html#ad551bb907b825c0086d85849a030b8fa", null ],
    [ "Visible", "servicecom_1_1sun_1_1star_1_1drawing_1_1Shape.html#a0d1d0fe42a221d48b7805c0543153169", null ],
    [ "ZOrder", "servicecom_1_1sun_1_1star_1_1drawing_1_1Shape.html#acbb4116553588b164d1490ee18737be3", null ]
];

==> libreoffice-fresh-sdk-25.8.3-3-x86_64.pkg.tar.zst: usr/share/doc/libreoffice/sdk/docs/idl/ref/servicecom_1_1sun_1_1star_1_1drawing_1_1Shape.js <==
var servicecom_1_1sun_1_1star_1_1drawing_1_1Shape =
[
    [ "InteropGrabBag", "servicecom_1_1sun_1_1star_1_1drawing_1_1Shape.html#a0757cef6c56ac96c756b2073c883f8ae", null ],
    [ "com::sun::star::beans::XPropertySet", "servicecom_1_1sun_1_1star_1_1drawing_1_1Shape.html#ae6872c0d73362de7c3f167030e03e1cf", null ],
    [ "com::sun::star::beans::XTolerantMultiPropertySet", "servicecom_1_1sun_1_1star_1_1drawing_1_1Shape.html#aeea8ad7e0ca85deb15bbed39a280557d", null ],
    [ "com::sun::star::drawing::XGluePointsSupplier", "servicecom_1_1sun_1_1star_1_1drawing_1_1Shape.html#a437cf9adf6d63835724f5abd22de65cc", null ],
    [ "com::sun::star::drawing::XShape", "servicecom_1_1sun_1_1star_1_1drawing_1_1Shape.html#adab20321c1eecb5d8434a81acc03fc20", null ],
    [ "com::sun::star::drawing::XShapeDescriptor", "servicecom_1_1sun_1_1star_1_1drawing_1_1Shape.html#acd261de4974c7d2c48cedc30b347ae29", null ],
    [ "com::sun::star::lang::XComponent", "servicecom_1_1sun_1_1star_1_1drawing_1_1Shape.html#a3ee2eab6ea072f036a4548a48b0ed454", null ],
    [ "Decorative", "servicecom_1_1sun_1_1star_1_1drawing_1_1Shape.html#a4cf36267af04677eb9cdb6526e4aecda", null ],
    [ "Description", "servicecom_1_1sun_1_1star_1_1drawing_1_1Shape.html#a34409fed9d39281ada2d7ec172a52f9b", null ],
    [ "Hyperlink", "servicecom_1_1sun_1_1star_1_1drawing_1_1Shape.html#a060c49c5081c74c87cec34f8bfea3293", null ],
    [ "LayerID", "servicecom_1_1sun_1_1star_1_1drawing_1_1Shape.html#af37feca849685e9af8103c6b080ec331", null ],
    [ "LayerName", "servicecom_1_1sun_1_1star_1_1drawing_1_1Shape.html#adbfb5217b3399f617da03fea11e225e8", null ],
    [ "MoveProtect", "servicecom_1_1sun_1_1star_1_1drawing_1_1Shape.html#ab69af988a6e1eda2516005022e0420b7", null ],
    [ "Name", "servicecom_1_1sun_1_1star_1_1drawing_1_1Shape.html#a7ee9065718e6628dc7791b756fa6c0f9", null ],
    [ "NavigationOrder", "servicecom_1_1sun_1_1star_1_1drawing_1_1Shape.html#add98d6f3aac48cbf5ccd23af708034d9", null ],
    [ "Printable", "servicecom_1_1sun_1_1star_1_1drawing_1_1Shape.html#ad75a741ee6d8f45340ba0bbb7771f05b", null ],
    [ "RelativeHeight", "servicecom_1_1sun_1_1star_1_1drawing_1_1Shape.html#a83747b4d8c0a4a01350c25dd4c9ca006", null ],
    [ "RelativeHeightRelation", "servicecom_1_1sun_1_1star_1_1drawing_1_1Shape.html#af17d6377d90affc191c24d0a7bca7320", null ],
    [ "RelativeWidth", "servicecom_1_1sun_1_1star_1_1drawing_1_1Shape.html#a0a141b19661d6b1ab1aeb9487d3c7396", null ],
    [ "RelativeWidthRelation", "servicecom_1_1sun_1_1star_1_1drawing_1_1Shape.html#adb0178cce657fa0437f1329934f2f60f", null ],
    [ "ShapeUserDefinedAttributes", "servicecom_1_1sun_1_1star_1_1drawing_1_1Shape.html#aff9c06d4f7e22a306bb583bda636e87a", null ],
    [ "SizeProtect", "servicecom_1_1sun_1_1star_1_1drawing_1_1Shape.html#a51d9e13d885023067ad0e080b1560b92", null ],
    [ "Style", "servicecom_1_1sun_1_1star_1_1drawing_1_1Shape.html#aa5ea39996be0cb26d1e9bc347db9304c", null ],
    [ "Title", "servicecom_1_1sun_1_1star_1_1drawing_1_1Shape.html#aa7b633091e7820b835d04d0d5fc197c7", null ],
    [ "Transformation", "servicecom_1_1sun_1_1star_1_1drawing_1_1Shape.html#ad551bb907b825c0086d85849a030b8fa", null ],
    [ "Visible", "servicecom_1_1sun_1_1star_1_1drawing_1_1Shape.html#a0d1d0fe42a221d48b7805c0543153169", null ],
    [ "ZOrder", "servicecom_1_1sun_1_1star_1_1drawing_1_1Shape.html#acbb4116553588b164d1490ee18737be3", null ]
];
